==> skytemple_randomizer-2.0.1-py3-none-any.whl: skytemple_randomizer/frontend/abstract.py <==
#  Copyright 2020-2024 Capypara and the SkyTemple Contributors
#
#  This file is part of SkyTemple.
#
#  SkyTemple is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  SkyTemple is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with SkyTemple.  If not, see <https://www.gnu.org/licenses/>.
from __future__ import annotations

from abc import abstractmethod, ABC
from typing import Callable, NamedTuple, Literal


class PortraitDebugLine(NamedTuple):
    status: Literal["success"] | Literal["skipped"] | Literal["failed"]
    monster_idx: str
    monster_name: str
    form_idx: str
    form_name: str
    traceback: str


class AbstractFrontend(ABC):
    @abstractmethod
    def idle_add(self, fn: Callable):
        """Run code in main thread, whenever next possible."""
        pass

    def portrait_debug__clear(self):
        """Clear the debug output for portrait debugging info, if supported."""
        pass

    def portrait_debug__add(self, line: PortraitDebugLine):
        """Add a new entry to the debug output for portrait debugging info, if supported"""
        pass

==> skytemple_randomizer-2.2.0-py3-none-any.whl: skytemple_randomizer/frontend/abstract.py <==
#  Copyright 2020-2024 Capypara and the SkyTemple Contributors
#
#  This file is part of SkyTemple.
#
#  SkyTemple is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  SkyTemple is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with SkyTemple.  If not, see <https://www.gnu.org/licenses/>.
from __future__ import annotations

from abc import abstractmethod, ABC
from typing import NamedTuple, Literal
from collections.abc import Callable


class PortraitDebugLine(NamedTuple):
    status: Literal["success"] | Literal["skipped"] | Literal["failed"]
    monster_idx: str
    monster_name: str
    form_idx: str
    form_name: str
    traceback: str


class AbstractFrontend(ABC):
    @abstractmethod
    def idle_add(self, fn: Callable):
        """Run code in main thread, whenever next possible."""
        pass

    def portrait_debug__clear(self):
        """Clear the debug output for portrait debugging info, if supported."""
        pass

    def portrait_debug__add(self, line: PortraitDebugLine):
        """Add a new entry to the debug output for portrait debugging info, if supported"""
        pass
